AlKetabResult class

Constructors

AlKetabResult({required int verseID, required int chapterNumber, required int verseNumber, required int pageNumber, required String text, String? explanation})
const
AlKetabResult.fromJson(Map<String, dynamic> json)
factory

Properties

chapterNumber int
final
explanation String?
final
hashCode int
The hash code for this object.
no setterinherited
pageNumber int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
verseID int
final
verseNumber int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited