ChaptersByQuarter class

Chapters grouped by Quarter (Rub al-Hizb). Public API - exposed to library consumers.

Constructors

ChaptersByQuarter({required int id, required int quarterNumber, required int hizbNumber, required int hizbFraction, required String arabicTitle, required String englishTitle, required List<Chapter> chapters, int? firstPage, Verse? firstVerse})
const

Properties

arabicTitle String
final
chapters List<Chapter>
final
englishTitle String
final
firstPage int?
final
firstVerse Verse?
final
hashCode int
The hash code for this object.
no setterinherited
hizbFraction int
final
hizbNumber int
final
id int
final
quarterNumber int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited