DataExportRepository class abstract

Repository for exporting and importing user data. Public API - exposed to library consumers.

Constructors

DataExportRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAllUserData() Future<void>
Clear all user data (bookmarks, history, etc.).
exportToJson({bool includeHistory = true}) Future<String>
Export user data to JSON string.
exportUserData({bool includeHistory = true}) Future<UserDataBackup>
Export all user data to a backup object.
importFromJson(String json, {bool mergeWithExisting = true}) Future<ImportResult>
Import user data from JSON string.
importUserData(UserDataBackup backup, {bool mergeWithExisting = true}) Future<ImportResult>
Import user data from a backup object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited