HiveSearchHistoryDao class

Hive-backed implementation of SearchHistoryDao.

Implemented types

Constructors

HiveSearchHistoryDao()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String id) Future<void>
override
deleteAll() Future<void>
override
deleteOlderThan(int timestamp) Future<void>
override
getByType(SearchType type, int limit) Future<List<SearchHistoryEntry>>
override
getPopular(int limit) Future<List<SearchSuggestion>>
override
getRecent(int limit) Future<List<SearchHistoryEntry>>
override
getSuggestions({String? prefix, int limit = 10}) Future<List<SearchSuggestion>>
override
insert(SearchHistoryEntry entry) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
watchRecent(int limit) Stream<List<SearchHistoryEntry>>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited