LastReadPosition class

Last read position for resuming reading. Public API - exposed to library consumers.

Constructors

LastReadPosition({required MushafType mushafType, required int chapterNumber, required int verseNumber, required int pageNumber, required int lastReadAt, double scrollPosition = 0.0})
const

Properties

chapterNumber int
final
hashCode int
The hash code for this object.
no setterinherited
lastReadAt int
final
mushafType MushafType
final
pageNumber int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPosition double
final
verseNumber int
final
verseReference String
Verse reference in format "chapter:verse".
no setter

Methods

isRecent() bool
Check if this position is recent (within last 7 days).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited