Loading class

Loading state.

Inheritance

Constructors

Loading()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isError bool
Check if result is error.
no setterinherited
isLoading bool
Check if result is loading.
no setterinherited
isSuccess bool
Check if result is successful.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

flatMap<R>(Result<R> transform(Never data)) Result<R>
Flat map success data to another Result.
inherited
getOrDefault(Never defaultValue) → Never
Get data if success, or return default value.
inherited
getOrNull() → Never
Get data if success, null otherwise.
inherited
getOrThrow() → Never
Get data if success, or throw exception if error.
inherited
map<R>(R transform(Never data)) Result<R>
Map success data to another type.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(void action(Object exception)) Result<Never>
Execute action if error.
inherited
onLoading(void action()) Result<Never>
Execute action if loading.
inherited
onSuccess(void action(Never data)) Result<Never>
Execute action if success.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited