MushafType enum

Supported Mushaf layouts that alter how verses map to pages. Public API - exposed to library consumers.

Inheritance
Available extensions

Values

hafs1441 → const MushafType

Modern layout (1441 Hijri)

hafs1405 → const MushafType

Traditional layout (1405 Hijri)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MushafType>
A constant List of the values in this enum, in order of their declaration.