ReadingHistory class

Reading history entry for analytics. Public API - exposed to library consumers.

Constructors

ReadingHistory({required String id, required int chapterNumber, required int verseNumber, required int pageNumber, required int timestamp, required int durationSeconds, required MushafType mushafType})
const

Properties

chapterNumber int
final
durationMinutes int
Duration in minutes.
no setter
durationSeconds int
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
mushafType MushafType
final
pageNumber int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
final
verseNumber int
final
verseReference String
Verse reference in format "chapter:verse".
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited