ReadingThemeData class
Color scheme data for a reading theme.
Constructors
Properties
- accentColor → Color
-
final
- backgroundColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryTextColor → Color
-
final
- surfaceColor → Color
-
final
- textColor → Color
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromTheme(
ReadingTheme theme) → ReadingThemeData - Get theme data for a reading theme.