ReciterTiming class

Timing data for a reciter. Used for audio-verse synchronization. Public API - exposed to library consumers.

Constructors

ReciterTiming({required int id, required String name, required String nameEn, required String rewaya, required String folderUrl, required List<ChapterTiming> chapters})
const
ReciterTiming.fromJson(Map<String, dynamic> json)
factory

Properties

chapters List<ChapterTiming>
final
folderUrl String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
name String
final
nameEn String
final
rewaya String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited