Part class
Domain model for Quran Part (Juz). Represents one of the 30 parts of the Quran. Public API - exposed to library consumers.
Constructors
Properties
- arabicTitle → String
-
final
- englishTitle → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → int
-
final
- number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getDisplayTitle(
{String languageCode = 'ar'}) → String - Get the display title based on current locale.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited